==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/KernelChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class KernelChaosSpecFluentImpl<A extends KernelChaosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements KernelChaosSpecFluent<A> {

    private String duration;
    private FailKernRequestBuilder failKernRequest;
    private String mode;
    private SchedulerSpecBuilder scheduler;
    private SelectorSpecBuilder selector;
    private String value;

    public KernelChaosSpecFluentImpl() {
    }

    public KernelChaosSpecFluentImpl(KernelChaosSpec instance) {
        this.withDuration(instance.getDuration()); 
        this.withFailKernRequest(instance.getFailKernRequest()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
    }

    public String getDuration() {
        return this.duration;
    }

    public A withDuration(String duration) {
        this.duration=duration; return (A) this;
    }

    public Boolean hasDuration() {
        return this.duration != null;
    }

    public A withNewDuration(StringBuilder arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(int[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(char[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(StringBuffer arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(byte[] arg1,int arg2) {
        return (A)withDuration(new String(arg1, arg2));
    }

    public A withNewDuration(byte[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(char[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withDuration(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewDuration(String arg1) {
        return (A)withDuration(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildFailKernRequest instead.
 * @return The buildable object.
 */
@Deprecated public FailKernRequest getFailKernRequest() {
        return this.failKernRequest!=null?this.failKernRequest.build():null;
    }

    public FailKernRequest buildFailKernRequest() {
        return this.failKernRequest!=null?this.failKernRequest.build():null;
    }

    public A withFailKernRequest(FailKernRequest failKernRequest) {
        _visitables.get("failKernRequest").remove(this.failKernRequest);
        if (failKernRequest!=null){ this.failKernRequest= new FailKernRequestBuilder(failKernRequest); _visitables.get("failKernRequest").add(this.failKernRequest);} return (A) this;
    }

    public Boolean hasFailKernRequest() {
        return this.failKernRequest != null;
    }

    public KernelChaosSpecFluent.FailKernRequestNested<A> withNewFailKernRequest() {
        return new FailKernRequestNestedImpl();
    }

    public KernelChaosSpecFluent.FailKernRequestNested<A> withNewFailKernRequestLike(FailKernRequest item) {
        return new FailKernRequestNestedImpl(item);
    }

    public KernelChaosSpecFluent.FailKernRequestNested<A> editFailKernRequest() {
        return withNewFailKernRequestLike(getFailKernRequest());
    }

    public KernelChaosSpecFluent.FailKernRequestNested<A> editOrNewFailKernRequest() {
        return withNewFailKernRequestLike(getFailKernRequest() != null ? getFailKernRequest(): new FailKernRequestBuilder().build());
    }

    public KernelChaosSpecFluent.FailKernRequestNested<A> editOrNewFailKernRequestLike(FailKernRequest item) {
        return withNewFailKernRequestLike(getFailKernRequest() != null ? getFailKernRequest(): item);
    }

    public String getMode() {
        return this.mode;
    }

    public A withMode(String mode) {
        this.mode=mode; return (A) this;
    }

    public Boolean hasMode() {
        return this.mode != null;
    }

    public A withNewMode(StringBuilder arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(int[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(char[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(StringBuffer arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(byte[] arg1,int arg2) {
        return (A)withMode(new String(arg1, arg2));
    }

    public A withNewMode(byte[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(char[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMode(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMode(String arg1) {
        return (A)withMode(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public SchedulerSpec buildScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public A withScheduler(SchedulerSpec scheduler) {
        _visitables.get("scheduler").remove(this.scheduler);
        if (scheduler!=null){ this.scheduler= new SchedulerSpecBuilder(scheduler); _visitables.get("scheduler").add(this.scheduler);} return (A) this;
    }

    public Boolean hasScheduler() {
        return this.scheduler != null;
    }

    public A withNewScheduler(String cron) {
        return (A)withScheduler(new SchedulerSpec(cron));
    }

    public KernelChaosSpecFluent.SchedulerNested<A> withNewScheduler() {
        return new SchedulerNestedImpl();
    }

    public KernelChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item) {
        return new SchedulerNestedImpl(item);
    }

    public KernelChaosSpecFluent.SchedulerNested<A> editScheduler() {
        return withNewSchedulerLike(getScheduler());
    }

    public KernelChaosSpecFluent.SchedulerNested<A> editOrNewScheduler() {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): new SchedulerSpecBuilder().build());
    }

    public KernelChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item) {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public SelectorSpec buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(SelectorSpec selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new SelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public KernelChaosSpecFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public KernelChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item) {
        return new SelectorNestedImpl(item);
    }

    public KernelChaosSpecFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public KernelChaosSpecFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new SelectorSpecBuilder().build());
    }

    public KernelChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    public String getValue() {
        return this.value;
    }

    public A withValue(String value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(StringBuilder arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(int[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(char[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(byte[] arg1,int arg2) {
        return (A)withValue(new String(arg1, arg2));
    }

    public A withNewValue(byte[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(char[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withValue(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewValue(String arg1) {
        return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KernelChaosSpecFluentImpl that = (KernelChaosSpecFluentImpl) o;
        if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
        if (failKernRequest != null ? !failKernRequest.equals(that.failKernRequest) :that.failKernRequest != null) return false;
        if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
        if (scheduler != null ? !scheduler.equals(that.scheduler) :that.scheduler != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(duration,  failKernRequest,  mode,  scheduler,  selector,  value,  super.hashCode());
    }

    public class FailKernRequestNestedImpl<N> extends FailKernRequestFluentImpl<KernelChaosSpecFluent.FailKernRequestNested<N>> implements KernelChaosSpecFluent.FailKernRequestNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final FailKernRequestBuilder builder;

            FailKernRequestNestedImpl(FailKernRequest item) {
                this.builder = new FailKernRequestBuilder(this, item);
                        
            }

            FailKernRequestNestedImpl() {
                this.builder = new FailKernRequestBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withFailKernRequest(builder.build());
            }

            public N endFailKernRequest() {
                return and();
            }
    }


    public class SchedulerNestedImpl<N> extends SchedulerSpecFluentImpl<KernelChaosSpecFluent.SchedulerNested<N>> implements KernelChaosSpecFluent.SchedulerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SchedulerSpecBuilder builder;

            SchedulerNestedImpl(SchedulerSpec item) {
                this.builder = new SchedulerSpecBuilder(this, item);
                        
            }

            SchedulerNestedImpl() {
                this.builder = new SchedulerSpecBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withScheduler(builder.build());
            }

            public N endScheduler() {
                return and();
            }
    }


    public class SelectorNestedImpl<N> extends SelectorSpecFluentImpl<KernelChaosSpecFluent.SelectorNested<N>> implements KernelChaosSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SelectorSpecBuilder builder;

            SelectorNestedImpl(SelectorSpec item) {
                this.builder = new SelectorSpecBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new SelectorSpecBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/KernelChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class KernelChaosSpecFluentImpl<A extends KernelChaosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements KernelChaosSpecFluent<A> {

    private String duration;
    private FailKernRequestBuilder failKernRequest;
    private String mode;
    private SchedulerSpecBuilder scheduler;
    private SelectorSpecBuilder selector;
    private String value;

    public KernelChaosSpecFluentImpl() {
    }

    public KernelChaosSpecFluentImpl(KernelChaosSpec instance) {
        this.withDuration(instance.getDuration()); 
        this.withFailKernRequest(instance.getFailKernRequest()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
    }

    public String getDuration() {
        return this.duration;
    }

    public A withDuration(String duration) {
        this.duration=duration; return (A) this;
    }

    public Boolean hasDuration() {
        return this.duration != null;
    }

    public A withNewDuration(StringBuilder arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(int[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(char[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(StringBuffer arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(byte[] arg1,int arg2) {
        return (A)withDuration(new String(arg1, arg2));
    }

    public A withNewDuration(byte[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(char[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withDuration(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewDuration(String arg1) {
        return (A)withDuration(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildFailKernRequest instead.
 * @return The buildable object.
 */
@Deprecated public FailKernRequest getFailKernRequest() {
        return this.failKernRequest!=null?this.failKernRequest.build():null;
    }

    public FailKernRequest buildFailKernRequest() {
        return this.failKernRequest!=null?this.failKernRequest.build():null;
    }

    public A withFailKernRequest(FailKernRequest failKernRequest) {
        _visitables.get("failKernRequest").remove(this.failKernRequest);
        if (failKernRequest!=null){ this.failKernRequest= new FailKernRequestBuilder(failKernRequest); _visitables.get("failKernRequest").add(this.failKernRequest);} return (A) this;
    }

    public Boolean hasFailKernRequest() {
        return this.failKernRequest != null;
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<A> withNewFailKernRequest() {
        return new FailKernRequestNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<A> withNewFailKernRequestLike(FailKernRequest item) {
        return new FailKernRequestNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<A> editFailKernRequest() {
        return withNewFailKernRequestLike(getFailKernRequest());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<A> editOrNewFailKernRequest() {
        return withNewFailKernRequestLike(getFailKernRequest() != null ? getFailKernRequest(): new FailKernRequestBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<A> editOrNewFailKernRequestLike(FailKernRequest item) {
        return withNewFailKernRequestLike(getFailKernRequest() != null ? getFailKernRequest(): item);
    }

    public String getMode() {
        return this.mode;
    }

    public A withMode(String mode) {
        this.mode=mode; return (A) this;
    }

    public Boolean hasMode() {
        return this.mode != null;
    }

    public A withNewMode(StringBuilder arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(int[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(char[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(StringBuffer arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(byte[] arg1,int arg2) {
        return (A)withMode(new String(arg1, arg2));
    }

    public A withNewMode(byte[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(char[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMode(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMode(String arg1) {
        return (A)withMode(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public SchedulerSpec buildScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public A withScheduler(SchedulerSpec scheduler) {
        _visitables.get("scheduler").remove(this.scheduler);
        if (scheduler!=null){ this.scheduler= new SchedulerSpecBuilder(scheduler); _visitables.get("scheduler").add(this.scheduler);} return (A) this;
    }

    public Boolean hasScheduler() {
        return this.scheduler != null;
    }

    public A withNewScheduler(String cron) {
        return (A)withScheduler(new SchedulerSpec(cron));
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<A> withNewScheduler() {
        return new SchedulerNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item) {
        return new SchedulerNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<A> editScheduler() {
        return withNewSchedulerLike(getScheduler());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<A> editOrNewScheduler() {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): new SchedulerSpecBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item) {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public SelectorSpec buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(SelectorSpec selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new SelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item) {
        return new SelectorNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new SelectorSpecBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    public String getValue() {
        return this.value;
    }

    public A withValue(String value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(StringBuilder arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(int[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(char[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(byte[] arg1,int arg2) {
        return (A)withValue(new String(arg1, arg2));
    }

    public A withNewValue(byte[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(char[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withValue(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewValue(String arg1) {
        return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KernelChaosSpecFluentImpl that = (KernelChaosSpecFluentImpl) o;
        if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
        if (failKernRequest != null ? !failKernRequest.equals(that.failKernRequest) :that.failKernRequest != null) return false;
        if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
        if (scheduler != null ? !scheduler.equals(that.scheduler) :that.scheduler != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(duration,  failKernRequest,  mode,  scheduler,  selector,  value,  super.hashCode());
    }

    public class FailKernRequestNestedImpl<N> extends FailKernRequestFluentImpl<io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<N>> implements io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.FailKernRequestNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final FailKernRequestBuilder builder;

            FailKernRequestNestedImpl(FailKernRequest item) {
                this.builder = new FailKernRequestBuilder(this, item);
                        
            }

            FailKernRequestNestedImpl() {
                this.builder = new FailKernRequestBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withFailKernRequest(builder.build());
            }

            public N endFailKernRequest() {
                return and();
            }
    }


    public class SchedulerNestedImpl<N> extends SchedulerSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<N>> implements io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SchedulerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SchedulerSpecBuilder builder;

            SchedulerNestedImpl(SchedulerSpec item) {
                this.builder = new SchedulerSpecBuilder(this, item);
                        
            }

            SchedulerNestedImpl() {
                this.builder = new SchedulerSpecBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withScheduler(builder.build());
            }

            public N endScheduler() {
                return and();
            }
    }


    public class SelectorNestedImpl<N> extends SelectorSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<N>> implements io.fabric8.chaosmesh.v1alpha1.KernelChaosSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SelectorSpecBuilder builder;

            SelectorNestedImpl(SelectorSpec item) {
                this.builder = new SelectorSpecBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new SelectorSpecBuilder(this);
                        
            }

            public N and() {
                return (N) KernelChaosSpecFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


}
